@@ -12,7 +12,7 @@ bn.fit = function(x, data, method = "mle", ..., debug = FALSE) {
   # check the fitting method (maximum likelihood, bayesian, etc.)
   check.fitting.method(method, data)
   # check the extra arguments.
-  extra.args = check.fitting.args(method, x, data, list(...)) 
+  extra.args = check.fitting.args(method, x, data, list(...))
 
   bn.fit.backend(x = x, data = data, method = method, extra.args = extra.args,
     debug = debug)
@@ -115,69 +115,6 @@ coef.bn.fit.dnode = function(object, ...) {
 
 }#COEF.BN.FIT.DNODE
 
-# estimate the predicted values for a particular node.
-predict.bn.fit = function(object, node, data, ...) {
-
-  # check the data are there.
-  check.data(data)
-  # a valid node is needed.
-  check.nodes(nodes = node, graph = object, max.nodes = 1)
-  # check the fitted model.
-  check.fit.vs.data(fitted = object, data = data)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
-  if (is.fitted.discrete(object))
-    discrete.prediction(node = node, fitted = object, data = data)
-  else
-    gaussian.prediction(node = node, fitted = object, data = data)
-
-}#PREDICT.BN.FIT
-
-# estimate the predicted values for a gaussian node.
-predict.bn.fit.gnode = function(object, data, ...) {
-
-  nodes = names(data)
-  target = object$node
-
-  # check the data are there.
-  check.data(data)
-  # a valid node is needed.
-  check.nodes(nodes = target, graph = nodes, max.nodes = 1)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
-  # create a dummy bn.fit object to pass to gaussian.prediction().
-  dummy = vector(length(nodes), mode = "list")
-  names(dummy) = nodes
-  dummy[[target]] = object
-  # compute the predicted values.
-  gaussian.prediction(node = target, fitted = dummy, data = data)
-
-}#PREDICT.BN.FIT.GNODE
-
-# estimate the predicted values for a discrete node.
-predict.bn.fit.dnode = function(object, data, ...) {
-
-  # check the data are there.
-  check.data(data)
-  # a valid node is needed.
-  check.nodes(nodes = target, graph = nodes, max.nodes = 1)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
-  nodes = names(data)
-  target = object$node
-
-  # create a dummy bn.fit object to pass to discrete.prediction().
-  dummy = vector(length(nodes), mode = "list")
-  names(dummy) = nodes
-  dummy[[target]] = object
-  # compute the predicted values.
-  discrete.prediction(node = target, fitted = dummy, data = data)
-
-}#PREDICT.BN.FIT.DNODE
-
 # logLik method for class 'bn.fit'.
 logLik.bn.fit = function(object, data, ...) {
 
