@@ -5,7 +5,7 @@ modelstring = function(x) {
   # check x's class.
   check.bn.or.fit(x)
   # no model string if the graph is partially directed.
-  if (class(x) == "bn")
+  if (is(x, "bn"))
     if (is.pdag(x$arcs, names(x$nodes)))
       stop("the graph is only partially directed.")
 
@@ -36,15 +36,28 @@ as.character.bn = function(x, ...) {
 }#AS.CHARACTER.BN
 
 # generate an object of class bn from a model string.
-model2network = function(string, debug = FALSE) {
+model2network = function(string, ordering = NULL, debug = FALSE) {
 
   # check string's class.
   if (!is(string, "character"))
     stop("string must be a character string.")
+  # check the node ordering; NULL is ok this time, it lets the backend decide.
+  if (!is.null(ordering))
+    check.nodes(ordering)
   # check debug.
   check.logical(debug)
 
-  model2network.backend(string, debug = debug)
+  result = model2network.backend(string, node.order = ordering, debug = debug)
+
+  # check the node ordering again now that the graph is built.
+  if (!is.null(ordering)) {
+
+    check.nodes(ordering, graph = result, min.nodes = length(result$nodes),
+      max.nodes = length(result$nodes))
+
+  }#THEN
+
+  return(result)
 
 }#MODEL2NETWORK
 
